==> boofcv-ip-0.33.1-sources.jar: boofcv/alg/distort/PointToPixelTransform_F32.java <==
/*
 * Copyright (c) 2011-2019, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.alg.distort;

import boofcv.struct.distort.PixelTransform;
import boofcv.struct.distort.Point2Transform2_F32;
import georegression.struct.point.Point2D_F32;

/**
 * Allows a {@link PointToPixelTransform_F32} to be invoked as a {@link PixelTransform}.
 *
 * @author Peter Abeles
 */
public class PointToPixelTransform_F32 implements PixelTransform<Point2D_F32> {
	Point2Transform2_F32 alg;

	public PointToPixelTransform_F32(Point2Transform2_F32 alg) {
		this.alg = alg;
	}

	public PointToPixelTransform_F32() {
	}

	public void setTransform(Point2Transform2_F32 transform) {
		this.alg = transform;
	}

	@Override
	public void compute(int x, int y, Point2D_F32 output ) {
		alg.compute(x,y,output);
	}

	@Override
	public PointToPixelTransform_F32 copy() {
		return new PointToPixelTransform_F32(alg.copy());
	}
}

==> boofcv-ip-0.34-sources.jar: boofcv/alg/distort/PointToPixelTransform_F32.java <==
/*
 * Copyright (c) 2011-2019, Peter Abeles. All Rights Reserved.
 *
 * This file is part of BoofCV (http://boofcv.org).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package boofcv.alg.distort;

import boofcv.struct.distort.PixelTransform;
import boofcv.struct.distort.Point2Transform2_F32;
import georegression.struct.point.Point2D_F32;

/**
 * Allows a {@link PointToPixelTransform_F32} to be invoked as a {@link PixelTransform}.
 *
 * @author Peter Abeles
 */
public class PointToPixelTransform_F32 implements PixelTransform<Point2D_F32> {
	Point2Transform2_F32 alg;

	public PointToPixelTransform_F32(Point2Transform2_F32 alg) {
		this.alg = alg;
	}

	public PointToPixelTransform_F32() {
	}

	public void setTransform(Point2Transform2_F32 transform) {
		this.alg = transform;
	}

	@Override
	public void compute(int x, int y, Point2D_F32 output ) {
		alg.compute(x,y,output);
	}

	@Override
	public PointToPixelTransform_F32 copyConcurrent() {
		return new PointToPixelTransform_F32(alg.copyConcurrent());
	}
}
